@@ -14,10 +14,10 @@
 #' cleared by calling [lintr::clear_cache()].
 #' @export
 lint <- function(pkg = ".", cache = TRUE, ...) {
-  check_suggested("lintr")
+  rlang::check_installed("lintr")
   pkg <- as.package(pkg)
 
-  message("Linting ", pkg$package, appendLF = FALSE)
+  cli::cli_alert_info("Linting {.pkg {pkg$package}}")
 
   check_dots_used(action = getOption("devtools.ellipsis_action", rlang::warn))
 
