@@ -1,18 +1,17 @@
 #' Set working directory.
 #'
-#' @param pkg package description, can be path or package name.  See
-#'   [as.package()] for more information
+#' @template devtools
 #' @param path path within package. Leave empty to change working directory
 #'   to package directory.
 #' @export
 wd <- function(pkg = ".", path = "") {
   pkg <- as.package(pkg)
-  path <- file.path(pkg$path, path)
+  path <- path(pkg$path, path)
 
-  if (!file.exists(path)) {
+  if (!file_exists(path)) {
     stop(path, " does not exist", call. = FALSE)
   }
 
-  message("Changing working directory to ", path)
+  cli::cli_alert_info("Changing working directory to {.path {path}}")
   setwd(path)
 }
